pub async fn init(pool: &SqlitePool) -> Result<()>Expand description
Create the access-control tables if they do not exist. Called by the composing server after the kernel migrations have run.
pub async fn init(pool: &SqlitePool) -> Result<()>Create the access-control tables if they do not exist. Called by the composing server after the kernel migrations have run.